PacketMetrics class

Constructors

PacketMetrics({required String deviceId, required bool packetSent, required bool packetDiscarded, required int delay, required DateTime dateTime, required int packetSize})

Properties

dateTime DateTime
final
delay int
final
deviceId String
final
hashCode int
The hash code for this object.
no setterinherited
packetDiscarded bool
final
packetSent bool
final
packetSize int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited