ImageService class

Constructors

ImageService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

downloadImage(String url) Future<Uint8List>
resizeImage(Uint8List imageBytes, {int width = 600, int height = 400}) Future<Uint8List>