DeviceStatusUtils class

Constructors

DeviceStatusUtils()

Properties

getreputationsByDevice Map<String, NodeReputation>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

reputationsByDevice Map<String, NodeReputation>
getter/setter pair

Static Methods

checkDeviceStatus(BuildContext context, NearbyHttpService nearbyHttpService) Future<void>